CONTENTS OF THIS FILE
---------------------

* Introduction
* Features
* Requirements
* Installation
* Configuration
* Working with the events
* Maintainers


INTRODUCTION
------------

This module intends to deal with the General Data Protection Regulation (GDPR)
that came into effect on 25th May 2018, and subsequently also similar
legislation around the world. The legislation requires websites that process
personal data to obtain a consent for processing that is unambiguous and involve
a clear affirmative action (an opt-in). From that date, if you are not compliant
or visibly working towards compliance, you run the risk of enforcement action,
which can include a fine of up to 20 million euros, or in the case of an
undertaking, up to 4% of their total global turnover of the preceding fiscal
year, whichever is higher.

This being said, if you don't process any data that identify individuals (keep
in mind that session id's and IP addresses identify someone), you may not need
this module.

DISCLAIMER: The above is not legal advice, and the module contributors take no
responsibility for your GDPR implementation.


FEATURES
------------

If you want to conditionally set cookies in your module, there is a javascript
function provided that returns TRUE if the current user has given his consent:

Drupal.eu_cookie_compliance.hasAgreed()


REQUIREMENTS
------------

This module requires no modules outside of Drupal core.


INSTALLATION
------------

1. Execute the command `composer require drupal/eu_cookie_compliance`.

2. Enable the module using drush or go to the "Extend" tab in your Drupal
   installation.

3. If desired, give the 'administer Cookie Compliance banner' permissions
   that allow users of certain roles access the administration page. You can do so
   on the admin/people/permissions page.

- There is also a 'display eu cookie compliance banner' permission that helps
  you show the banner to the roles you desire.

4. You may want to create a page that would explain how your site uses cookies.
   Alternatively, if you have a privacy policy, you can link the banner to that
   page (see next step).

5. Go to the admin/config/system/eu-cookie-compliance/settings page to configure
   and enable the banner.

6. If you want to theme your banner, override the templates in your theme.

7. If you want to show the message in certain countries only, install the Smart IP
   module: http://drupal.org/project/smart_ip and enable regions on the admin page.


CONFIGURATION
--------------

A fully customizable banner which is used to gather consent for storing cookies
on the visitor's computer.

Configurable Information
----------------------------------------------
- Permissions
- Consent for processing of personal information
- Disable JavaScripts
- Cookie handling
- Store record of consent
- Cookie information banner
- Withdraw consent
- Privacy policy
- Appearance


WORKING WITH THE EVENTS
-----------------------

This module now exposes a JS API which other modules can use to hook into the
events fired by this module. Eg. read the cookie preferences when they are saved
or do something based on the user's response. For example the JS in the [EU
Cookie Compliance GTM
module](https://www.drupal.org/project/eu_cookie_compliance_gtm) uses the Events
to do things with GTM.

### Inside the scripts

#### Main file
Our main script (`eu_cookie_compliance.js`) loads via `defer`, which means it is
executed while parsing the page + just a few moments BEFORE the DOMContentLoaded
event gets fired. When that happens, a namespace is created within the Drupal
object, which will house our Events. Inside this namespace, a queue houses
instances when the Events hooks are called, ready to be executed.

```
Drupal.eu_cookie_compliance = Drupal.eu_cookie_compliance || function () {
  (Drupal.eu_cookie_compliance.queue = Drupal.eu_cookie_compliance.queue ||
[]).push(arguments);
};
```

This ensures that a script from another module (which
either should not use `defer`, or should be placed AFTER the main script in the
HTML) will be able to access the Events from the main script and perform
actions. _Note: This is very similar to how GA and GTM work with their events
and methods._ Besides a queue, there are special functions set up called
'Observers', which are used to observe and execute the functions for each Event.

**Events: (Event name on the left)** Status is retrieved (internal use):
- preStatusLoad: Executed BEFORE cookie acceptance status is loaded
- postStatusLoad: Executed AFTER cookie acceptance status is loaded
- preStatusSave: Executed BEFORE cookie acceptance status is saved
- postStatusSave Executed AFTER cookie acceptance status is saved

Cookie is accepted by the user (public use):
- prePreferencesSave: Executed
  BEFORE the cookie acceptance preferences are saved (to a cookie).
- postPreferencesSave: Executed AFTER the cookie acceptance preferences are saved
  (to a cookie).
- prePreferencesLoad: Executed BEFORE the cookie acceptance
  preferences are loaded (from a cookie)
- postPreferencesLoad: Executed AFTER the
  cookie acceptance preferences are loaded (from a cookie)

#### Secondary file

**How to hook into the events:** Use this method in your JS, where `MY_EVENT`
should be replaced by one of the Events mentioned above and `MY_HANDLER` is a
function that reads the data provided by the Method
`Drupal.eu_cookie_compliance(MY_EVENT, MY_HANDLER);` Example: reading the cookie
preferences after submission + save it somewhere else for later use
```
var postPreferencesLoadHandler = function(response) {
  console.log(response);
  window.cookieResponse = response;
};
Drupal.eu_cookie_compliance('postPreferencesLoad', postPreferencesLoadHandler);
```

The `response` variable is an object with the following structure:

```
{
  currentStatus: null (not yet agreed/withdrawn), 0 (declined), 1 (accepted,
show thank you banner) or 2 (accepted),
  currentCategories: array of accepted categories (will be empty when not using category based compliance)
}
```

MAINTAINERS
-----------

* Marcin Pajdzik - https://www.drupal.org/u/marcin-pajdzik
* Neslee Canil Pinto - https://www.drupal.org/u/neslee-canil-pinto
* Sven Berg Ryen - https://www.drupal.org/u/svenryen
