/**
 * @file
 * Cookie Compliance script.
 */

(function ($, Drupal) {

  'use strict';

  /**
   * Binds a listener on dialog creation to handle assigning ajax handlers to buttons.
   *
   * @param {jQuery.Event} e
   *   The event triggered.
   * @param {Drupal.dialog~dialogDefinition} dialog
   *   The dialog instance.
   * @param {jQuery} $element
   *   The jQuery collection of the dialog element.
   * @param {object} [settings]
   *   Dialog settings.
   */
  $(window).on('dialog:aftercreate', (e, dialog, $element, settings) => {
    /* For some reason, on the second jQuery dialog, we lose the connection
     * between the button and the form, and the JSON output ends up in the
     * browser window instead of being sent as an AJAX response.
     */

    // Find the submit button and set up the variables.
    const $submitButtons = $element.find('.form-submit');
    const $form = $element.find('form');
    const id = $submitButtons.attr('id');
    const url = $form.find('input[name=url]').val();

    // Check if we already have an ajax call for the button.
    for (let instance in Drupal.ajax.instances) {
      if (Drupal.ajax.instances[instance] !== null && typeof Drupal.ajax.instances[instance] !== 'undefined' && Drupal.ajax.instances[instance].url === url && Drupal.ajax.instances[instance].selector === '#' + id && Drupal.ajax.instances[instance].event === 'click') {
        return;
      }
    }

    // Initialize ajax handler for the form.
    var ajax = new Drupal.Ajax($submitButtons.id, $submitButtons[0], {
      '$form': $element,
      'dialogType': 'ajax',
      'disable-refocus': false,
      'event': 'click',
      'selector': $submitButtons.id,
      'submit': {
        'js': true,
      },
      'url': url
    });
    ajax.instanceIndex = Drupal.ajax.instances.length;
    Drupal.ajax.instances.push(ajax);

    // Make sure we don't submit the form back to the page.
    $submitButtons.click(function (e) {
      e.preventDefault();
    });
  });

} (jQuery, Drupal));
