/**
 * @file
 * Cookie Compliance behaviors.
 */

(function ($, Drupal) {

  'use strict';

  Drupal.AjaxCommands.prototype.updateCookiePrefsListCommand = function (ajax, response, status) {
    const $element = $(response.selector);
    const prefsList = response.prefsList;
    const prefsType = response.prefsType;
    const prefsTypeMachineName = response.prefsType.replaceAll('-', '_');

    // Get the currently selected options.
    let options = $element.find('input');
    let selectedOptions = [];
    let newValues = '';
    let prefsHyphened = '';

    options.each(function (option) {
      if (options[option].checked) {
        selectedOptions.push(options[option].name);
      }
    });

    // Update the list of displayed options.
    for (let prefs in prefsList) {
      prefsHyphened = prefs.toLowerCase().replaceAll('_','-');

      newValues += '<div class="js-form-item form-item js-form-type-checkbox form-type--checkbox form-type--boolean js-form-item-' + prefsType + '-' + prefsHyphened + ' form-item--' + prefsType + '-' + prefsHyphened + '">' +
        '<input data-drupal-selector="edit-' + prefsType + '-' + prefsHyphened + '" type="checkbox" id="edit-' + prefsType + '-' + prefsHyphened + '" name="' + prefsTypeMachineName + '[' + prefs + ']" value="' + prefs + '" class="form-checkbox form-boolean form-boolean--type-checkbox">\n' +
        '<label for="edit-' + prefsType + '-' + prefsHyphened + '" class="form-item__label option">' + prefsList[prefs] + ' <a href="/eu-cookie-compliance/edit-' + prefsType + '/' + prefs + '" class="use-ajax" data-dialog-type="modal" data-dialog-options="{&quot;width&quot;: 640}">Edit</a></label></div>';
    }

    $element.html(newValues);

    // Re-select the displayed options.
    for (let option in selectedOptions) {
      $('input[name="' + selectedOptions[option] + '"]').attr('checked', 'checked');
    }

    Drupal.behaviors.AJAX.attach(document, drupalSettings);
  };


} (jQuery, Drupal));
