<?php

namespace Drupal\eu_cookie_compliance;

use Drupal\Core\Entity\BundlePermissionHandlerTrait;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\eu_cookie_compliance\Entity\CookieComplianceSet;

/**
 * Provides dynamic permissions for Cookie Compliance sets.
 */
class CookieComplianceSetPermissions {
  use BundlePermissionHandlerTrait;
  use StringTranslationTrait;

  /**
   * Returns an array of CC set permissions.
   *
   * @return array
   *   The CC set permissions.
   *   @see \Drupal\user\PermissionHandlerInterface::getPermissions()
   */
  public function cookieComplianaceSetPermissions() {
    return $this->generatePermissions(CookieComplianceSet::loadMultiple(), [$this, 'buildPermissions']);
  }

  /**
   * Returns a list of CC Set permissions for a given CC Set.
   *
   * @param \Drupal\eu_cookie_compliance\Entity\CookieComplianceSet $type
   *   The Cookie Compliance Set.
   *
   * @return array
   *   An associative array of permission names and descriptions.
   */
  protected function buildPermissions(CookieComplianceSet $type) {
    $type_id = $type->id();
    $type_params = ['%type_name' => $type->label()];

    return [
      "display eu cookie compliance banner $type_id" => [
        'title' => $this->t('%type_name: Display Cookie Compliance Banner', $type_params),
      ],
    ];
  }

}
