<?php

namespace Drupal\eu_cookie_compliance\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\eu_cookie_compliance\CookieBannerInterface;

/**
 * Defines the cookie banner entity type.
 *
 * @ConfigEntityType(
 *   id = "cookie_banner",
 *   label = @Translation("Cookie Banner/Dialog"),
 *   label_collection = @Translation("Cookie Banners/Dialogs"),
 *   label_singular = @Translation("cookie banner"),
 *   label_plural = @Translation("cookie banners"),
 *   label_count = @PluralTranslation(
 *     singular = "@count cookie banner",
 *     plural = "@count cookie banners",
 *   ),
 *   handlers = {
 *     "list_builder" = "Drupal\eu_cookie_compliance\CookieBannerListBuilder",
 *     "form" = {
 *       "add" = "Drupal\eu_cookie_compliance\Form\CookieBannerForm",
 *       "edit" = "Drupal\eu_cookie_compliance\Form\CookieBannerForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm"
 *     }
 *   },
 *   config_prefix = "cookie_banner",
 *   admin_permission = "administer eu cookie compliance banner",
 *   links = {
 *     "collection" = "/admin/config/system/eu-cookie-compliance/cookie-banner",
 *     "add-form" = "/admin/config/system/eu-cookie-compliance/cookie-banner/add",
 *     "edit-form" = "/admin/config/system/eu-cookie-compliance/cookie-banner/{cookie_banner}",
 *     "delete-form" = "/admin/config/system/eu-cookie-compliance/cookie-banner/{cookie_banner}/delete"
 *   },
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "type",
 *     "message",
 *     "style",
 *     "formatting",
 *     "banner_dialog_background_color",
 *     "banner_dialog_text_color",
 *     "banner_dialog_border_width",
 *     "banner_dialog_border_color",
 *     "enable_privacy_policy_button",
 *     "privacy_policy_button_label",
 *     "privacy_policy_button_text_color",
 *     "privacy_policy_button_background_color",
 *     "privacy_policy_button_border_color",
 *     "privacy_policy_button_border_width",
 *     "enable_accept_all_button",
 *     "accept_all_button_label",
 *     "accept_all_button_text_color",
 *     "accept_all_button_background_color",
 *     "accept_all_button_border_width",
 *     "accept_all_button_border_color",
 *     "enable_reject_all_button",
 *     "reject_all_button_label",
 *     "reject_all_button_text_color",
 *     "reject_all_button_background_color",
 *     "reject_all_button_border_width",
 *     "reject_all_button_border_color",
 *     "enable_preferences_button",
 *     "preferences_button_label",
 *     "preferences_button_text_color",
 *     "preferences_button_background_color",
 *     "preferences_button_border_color",
 *     "preferences_button_border_width",
 *     "preferences_open_dialog_id",
 *     "enable_save_preferences_button",
 *     "save_preferences_button_label",
 *     "save_preferences_button_text_color",
 *     "save_preferences_button_background_color",
 *     "save_preferences_button_border_color",
 *     "save_preferences_button_border_width",
 *     "enable_settings_tab",
 *     "settings_tab_label",
 *     "settings_tab_background_color",
 *     "settings_tab_text_color",
 *     "settings_tab_border_color",
 *     "settings_tab_border_width",
 *     "enable_withdraw_button",
 *     "withdraw_message",
 *     "withdraw_button_label",
 *     "withdraw_button_background_color",
 *     "withdraw_button_text_color",
 *     "withdraw_button_border_width",
 *     "withdraw_button_border_color",
 *     "containing_element",
 *     "close_button_action",
 *     "close_button_enabled",
 *     "height",
 *     "width",
 *     "enable_categories_display",
 *     "load_at"
 *   }
 * )
 */
class CookieBanner extends ConfigEntityBase implements CookieBannerInterface {

  /**
   * The cookie banner ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The cookie banner label.
   *
   * @var string
   */
  protected $label;

  /**
   * The banner type (Bottom, top, top fixed, dialog, sidebar).
   *
   * @var string
   */
  protected $type;

  /**
   * Message.
   *
   * @var string
   */
  protected $message;

  /**
   * Withdraw message.
   *
   * @var string
   */
  protected $withdraw_message;

  /**
   * Style.
   *
   * @var string
   */
  protected $style;

  /**
   * Formatting.
   *
   * @var string
   */
  protected $formatting;

  /**
   * Banner/dialog background color.
   *
   * @var string
   */
  protected $banner_dialog_background_color;

  /**
   * Banner/dialog text color.
   *
   * @var string
   */
  protected $banner_dialog_text_color;

  /**
   * Banner/dialog border width.
   *
   * @var string
   */
  protected $banner_dialog_border_width;

  /**
   * Banner/dialog border color.
   *
   * @var string
   */
  protected $banner_dialog_border_color;

  /**
   * Enable privacy policy button.
   *
   * @var bool
   */
  protected $enable_privacy_policy_button;

  /**
   * The Privacy policy button label.
   *
   * @var string
   */
  protected $privacy_policy_button_label;

  /**
   * Privacy policy button text color.
   *
   * @var string
   */
  protected $privacy_policy_button_text_color;

  /**
   * Privacy policy button background color.
   *
   * @var string
   */
  protected $privacy_policy_button_background_color;

  /**
   * Privacy policy button border color.
   *
   * @var string
   */
  protected $privacy_policy_button_border_color;

  /**
   * Privacy policy button border width.
   *
   * @var string
   */
  protected $privacy_policy_button_border_width;

  /**
   * Enable accept all button.
   *
   * @var bool
   */
  protected $enable_accept_all_button;

  /**
   * Accept all button label.
   *
   * @var string
   */
  protected $accept_all_button_label;

  /**
   * Accept all button text color.
   *
   * @var string
   */
  protected $accept_all_button_text_color;

  /**
   * Accept all button background color.
   *
   * @var string
   */
  protected $accept_all_button_background_color;

  /**
   * Accept all button border width.
   *
   * @var string
   */
  protected $accept_all_button_border_width;

  /**
   * Accept all button border color.
   *
   * @var string
   */
  protected $accept_all_button_border_color;

  /**
   * Enable reject all button.
   *
   * @var bool
   */
  protected $enable_reject_all_button;

  /**
   * Reject all button label.
   *
   * @var string
   */
  protected $reject_all_button_label;

  /**
   * Reject all button text color.
   *
   * @var string
   */
  protected $reject_all_button_text_color;

  /**
   * Reject all button background color.
   *
   * @var string
   */
  protected $reject_all_button_background_color;

  /**
   * Reject all button border width.
   *
   * @var string
   */
  protected $reject_all_button_border_width;

  /**
   * Reject all button border color.
   *
   * @var string
   */
  protected $reject_all_button_border_color;

  /**
   * Enable preferences button.
   *
   * @var bool
   */
  protected $enable_preferences_button;

  /**
   * Preferences button label.
   *
   * @var string
   */
  protected $preferences_button_label;

  /**
   * Preferences button text color.
   *
   * @var string
   */
  protected $preferences_button_text_color;

  /**
   * Preferences button background color.
   *
   * @var string
   */
  protected $preferences_button_background_color;

  /**
   * Preferences button border color.
   *
   * @var string
   */
  protected $preferences_button_border_color;

  /**
   * Preferences button border width.
   *
   * @var string
   */
  protected $preferences_button_border_width;

  /**
   * Preferences dialog to open.
   *
   * @var string
   */
  protected $preferences_open_dialog_id;

  /**
   * Enable save preferences button.
   *
   * @var bool
   */
  protected $enable_save_preferences_button;

  /**
   * Save preferences button label.
   *
   * @var string
   */
  protected $save_preferences_button_label;

  /**
   * Save preferences button text color.
   *
   * @var string
   */
  protected $save_preferences_button_text_color;

  /**
   * Save preferences button background color.
   *
   * @var string
   */
  protected $save_preferences_button_background_colo;

  /**
   * Save preferences button border color.
   *
   * @var string
   */
  protected $save_preferences_button_border_color;

  /**
   * Save preferences button border width.
   *
   * @var string
   */
  protected $save_preferences_button_border_width;

  /**
   * Enable privacy settings tab.
   *
   * @var bool
   */
  protected $enable_settings_tab;

  /**
   * Privacy settings tab label.
   *
   * @var string
   */
  protected $settings_tab_label;

  /**
   * Privacy settings tab background color.
   *
   * @var string
   */
  protected $settings_tab_background_color;

  /**
   * Privacy settings tab text color.
   *
   * @var string
   */
  protected $settings_tab_text_color;

  /**
   * Privacy settings tab border color.
   *
   * @var string
   */
  protected $settings_tab_border_color;

  /**
   * Privacy settings tab border width.
   *
   * @var string
   */
  protected $settings_tab_border_width;

  /**
   * Enable withdraw consent action button.
   *
   * @var bool
   */
  protected $enable_withdraw_button;

  /**
   * Withdraw consent action button label.
   *
   * @var string
   */
  protected $withdraw_button_label;

  /**
   * Withdraw consent action button background color.
   *
   * @var string
   */
  protected $withdraw_button_background_color;

  /**
   * Withdraw consent action button text color.
   *
   * @var string
   */
  protected $withdraw_button_text_color;

  /**
   * Withdraw consent action button border width.
   *
   * @var string
   */
  protected $withdraw_button_border_width;

  /**
   * Withdraw consent action button border color.
   *
   * @var string
   */
  protected $withdraw_button_border_color;

  /**
   * Containing element.
   *
   * @var string
   */
  protected $containing_element;

  /**
   * Close button action.
   *
   * @var string
   */
  protected $close_button_action;

  /**
   * Close button/box enabled.
   *
   * @var bool
   */
  protected $close_button_enabled;

  /**
   * Banner/dialog height.
   *
   * @var string
   */
  protected $height;

  /**
   * Banner/dialog width.
   *
   * @var string
   */
  protected $width;

  /**
   * Enable categories display.
   *
   * @var bool
   */
  protected $enable_categories_display;

  /**
   * Load at.
   *
   * @var string
   */
  protected $load_at;

}
